@@ -8,20 +8,22 @@ package Test::Class::Moose::Tutorial
 
 1;
 {
-  $Test::Class::Moose::Tutorial::VERSION = '0.22';
+  $Test::Class::Moose::Tutorial::VERSION = '0.40';
 }
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Tutorial - A starting guide for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.22
+version 0.40
 
 =head1 Getting Started
 
@@ -66,7 +68,7 @@ as a test.
     use My::Module;
 
     sub test_construction {
-        my ( $test, $report ) = @_;
+        my $test = shift;
         my $obj = My::Module->new;
         isa_ok $obj, 'My::Module';
     }
@@ -206,7 +208,7 @@ If you need to prepare a plan for your tests, you can do so using the plan()
 method:
 
     sub test_constructor {
-        my ( $test, $report ) = @_;
+        my $test = shift;
         $test->plan( 1 ); # 1 test in this sub
         isa_ok My::Module->new, 'My::Module';
     }
@@ -229,8 +231,8 @@ and call the C<test_skip> method with the reason we're skipping the test.
     }
     
     sub test_setup {
-        my ( $test, $report ) = @_;
-        if ( $report->name eq 'test_will_fail' ) {
+        my $test = shift;
+        if ( $test->test_report->current_method->name eq 'test_will_fail' ) {
             $test->test_skip( 'It doesn't work' );
         }
     }
@@ -239,7 +241,7 @@ If we don't want to run an entire class, we can use the C<test_startup> method
 and the same C<test_skip> method with the reason we're skipping the test.
 
     sub test_startup {
-        my ( $test, $report ) = @_;
+        my $test = shift;
         $test->test_skip( "The entire class doesn't work" );
     }
 
@@ -344,7 +346,7 @@ Curtis "Ovid" Poe <ovid@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Curtis "Ovid" Poe.
+This software is copyright (c) 2014 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
